# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 7/24/2023 3:56 PM
@Description: Description
@File: base_dto.py
"""
import mimetypes
import os
from dataclasses import dataclass, fields, Field
from typing import Dict, Any, TypeVar, Type, List, get_origin

T = TypeVar('T', bound='BaseDto')


@dataclass
class BaseDto:

    def __getattr__(self, name):
        raise AttributeError(f"'{type(self).__name__}' object has no attribute '{name}'")

    def __setattr__(self, key, value):
        if key not in [field.name for field in fields(self)]:
            raise AttributeError(f"'{type(self).__name__}' object has no attribute '{key}'")
        super().__setattr__(key, value)

    def data(self, has_none_value=True):
        tmp = dict()
        for k, v in self.__dict__.items():
            if v is None and has_none_value is False:
                continue
            tmp.update({k: v})
        return tmp

    def to_dict(self) -> Dict[str, Any]:
        data = dict()
        for f in fields(self):
            key = f.metadata.get('alias', f.name)
            value = getattr(self, f.name)
            multipart_file = f.metadata.get('multipart_file', False)
            if multipart_file:
                value = process_multipart_file(value)
            elif isinstance(value, BaseDto):
                value = value.to_dict()
            elif isinstance(value, list):
                value = [item.to_dict() if isinstance(item, BaseDto) else item for item in value]
            elif isinstance(value, set):  # 20241104在Python的requests库中，传递JSON数据时，set类型并不是JSON可序列化的格式，
                # 因此需要将 set 转换为其他类型（如 list）才能正确发送
                value = list(value)
            if not f.metadata.get('ignore', False):
                data[key] = value
        return data

    @classmethod
    def from_dict(cls: Type[T], data: Dict[str, Any]) -> T:
        kwargs = dict()
        for f in fields(cls):
            key = f.metadata.get("alias", f.name)
            if key in data:
                kwargs[f.name] = convert_value(f, data[key])
        return cls(**kwargs)

    def build_multipart_fields(self, values_as_str=False, has_none=True) -> List[tuple[str, Any]]:
        data = list()
        for f in fields(self):
            key = f.metadata.get('alias', f.name)
            value = getattr(self, f.name)
            multipart_file = f.metadata.get('multipart_file', False)
            if multipart_file:
                value = process_multipart_file(value)
            if isinstance(value, BaseDto):
                value = value.to_dict()
            elif isinstance(value, list):
                value = [item.to_dict() if isinstance(item, BaseDto) else item for item in value]
            if not f.metadata.get('ignore', False):
                # if multipart_file and isinstance(value, list):
                #     data.extend((key, i) for i in value)
                # elif isinstance(value, list):
                #     for i in value:
                #         if isinstance(i, BaseDto):
                #             data.append((key, i.to_dict()))
                #         elif values_as_str and i is not None:
                #             data.append((key, str(i)))
                #         else:
                #             data.append((key, i))
                # else:
                #     if not has_none and value is None:
                #         continue
                #     data.append((key, str(value) if values_as_str and value is not None else value))
                if value and isinstance(value, (list, dict)):
                    if isinstance(value, list) and all(isinstance(i, (str, int)) for i in value):
                        data.extend([(key, str(i)) if values_as_str else (key, i) for i in value])
                    else:
                        data.extend(tuple(
                            flatten_data(value, parent_key=key, has_none=has_none,
                                         values_as_str=values_as_str).items()))
                else:
                    if not has_none and (value is None or (isinstance(value, (list, dict)) and not value)):
                        continue
                    data.append((key, str(value) if values_as_str and value is not None else value))
        return data

    @classmethod
    def has_multipart_file_field(cls) -> bool:
        for f in fields(cls):
            if f.metadata.get("multipart_file", False):
                return True
        return False


def convert_value(field: Field, value: Any) -> Any:
    origin = get_origin(field.type)
    if origin is not None:
        return value
    if isinstance(value, field.type):
        return value
    elif isinstance(value, (dict, int)) and field.type is str:
        return str(value)
    elif isinstance(value, str) and field.type is int:
        if value.isdigit():
            return int(value)
        else:
            return value
    else:
        return value


def build_file_dto(file_path):
    return os.path.basename(file_path), open(file_path, 'rb'), next(iter(mimetypes.guess_type(file_path)))


def process_multipart_file(value):
    """处理 multipart_file 类型的值"""
    if isinstance(value, str):
        if os.path.exists(value) and os.path.isfile(value):
            return build_file_dto(value)
        else:
            raise ValueError(f"无效的文件路径: {value}")
    elif isinstance(value, list):
        if all(isinstance(i, str) and os.path.exists(i) and os.path.isfile(i) for i in value):
            return [build_file_dto(i) for i in value]
        else:
            raise ValueError(f"列表中包含无效的文件路径: {value}")
    return value


def flatten_data(data, parent_key='', sep='.', values_as_str=False, has_none=True):
    items = []
    if isinstance(data, dict):
        for k, v in data.items():
            if not has_none and v is None:
                continue
            new_key = f"{parent_key}{sep}{k}" if parent_key else k
            items.extend(flatten_data(v, new_key, sep=sep, values_as_str=values_as_str, has_none=has_none).items())
    elif isinstance(data, list):
        for idx, v in enumerate(data):
            if not has_none and v is None:
                continue
            new_key = f"{parent_key}[{idx}]"
            items.extend(flatten_data(v, new_key, sep=sep, values_as_str=values_as_str, has_none=has_none).items())
    else:
        if not has_none and data is None:
            return dict()
        items.append(
            (parent_key, str(data) if values_as_str and data is not None and not isinstance(data, tuple) else data))
    return dict(items)



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 5/22/2025 4:57 PM
@Description: Description
@File: decrypt.py
"""
import base64
import re

from Crypto.Cipher import AES


def decrypt(str_base64: str, is_no_padding: bool = False) -> str:
    key = b'1234567890123456'
    iv = b'1234567890123456'

    # Base64 解码
    ciphertext = base64.b64decode(str_base64)

    # 创建 AES 解密器
    mode = AES.MODE_CBC
    cipher = AES.new(key, mode, iv=iv)

    # 解密
    decrypted = cipher.decrypt(ciphertext)

    if not is_no_padding:
        # 去除 PKCS#7 padding
        pad_len = decrypted[-1]
        decrypted = decrypted[:-pad_len]

    # 转成字符串（UTF-8 解码）
    decrypted_str = decrypted.decode('utf-8', errors='replace')

    # 替换不可见字符（与 JS 中 replace(/[\u0000-\u001F\u007F-\u009F]/g, ' ') 等效）
    cleaned_str = re.sub(r'[\x00-\x1F\x7F-\x9F]', ' ', decrypted_str)

    return cleaned_str



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/09/06 14:41
@Description: Description
@File: subject_auth_service.py
"""
from api_requester.core.admin.api.subject_auth_api import AdminSubjectAuthApi
from api_requester.core.admin.dto.jwt_authentication_request import JwtAuthenticationRequest
from api_requester.core.admin.dto.subject_jwt_authentication_request import SubjectJwtAuthenticationRequest


class AdminSubjectAuthService(AdminSubjectAuthApi):
    """
    The AdminSubjectAuthService was generated by Generator from the SubjectAuthController.java file.
    """

    def __init__(self):
        AdminSubjectAuthApi.__init__(self)

    def auth_subject_login(self, authentication_request: SubjectJwtAuthenticationRequest = None):
        return self.auth_subject_login_api(json=authentication_request)

    def auth_subject_logout(self):
        return self.auth_subject_logout_api()

    def auth_subject_me(self):
        return self.auth_subject_me_api()

    def verify_organization_code(self, organization_code: str = None):
        return self.verify_organization_code_api(params=dict(organizationCode=organization_code))



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: jwt_authentication_request.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class JwtAuthenticationRequest(BaseDto):
    """
    The JwtAuthenticationRequest was generated by Generator from the JwtAuthenticationRequest.java file.
    """
    userName: str
    password: str
    mfaToken: str = None



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 03/18/2024 3:48 PM
@Description: Description
@File: authorize.py
"""


class EClinicalUser:

    def __init__(self, username=None, password=None, sponsor=None, study=None, test_env=None, app_env=None, app=None,
                 company=None, role=None, external=False, org_code=None):
        # username 用户名
        # password 密码
        # app 访问的系统
        # sponsor 访问sponsor 如果不需要，则传None
        # study 访问sponsor 如果不需要，则传None
        # test_env 访问的服务器环境
        self.username = username
        self.password = password
        self.app = app
        self.sponsor = sponsor
        self.study = study
        self.app_env = app_env
        self.test_env = str(test_env) if test_env is not None else None
        self.company = company
        self.role = role
        self.external = external
        self.company_level_login = False
        self.org_code = org_code

    def __repr__(self):
        attributes = self.__dict__
        info = [
            str(attributes[item]) for item in
            ["test_env", "username", "role", "company", "sponsor", "study", "app_env", "org_code"]
            if attributes.get(item) is not None
        ]
        return "/".join(info)



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/26 19:01
@Description: Description
@File: sso_token_retrieve_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class SsoTokenRetrieveDto(BaseDto):
    """
    The SsoTokenRetrieveDto was generated by Generator from the SsoTokenRetrieveDto.java file.
    """
    tokenId: str
    userName: str



"""
Created on Mar 17, 2020

@author: xiaodong.li
"""
import os
import sys

from loguru import logger

from api_requester.utils.path import root


def init_logger(log_filename="app.log", level="DEBUG"):
    log_dir = get_writable_log_path()
    logger.remove()
    logger.add(
        sys.stdout,
        level=level,
        format="<green>{time:YYYY-MM-DD HH:mm:ss}</green> | "
               "<level>{level}</level> | "
               "<cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - "
               "<level>{message}</level>"
    )
    logger.add(
        os.path.join(log_dir, log_filename),
        level=level,
        rotation="00:00",  # 每天午夜切分
        retention="7 days",  # 最多保留7天
        compression="zip",  # 自动压缩旧日志
        encoding="utf-8",
        enqueue=True  # 支持多进程
    )


def get_writable_log_path():
    if getattr(sys, 'frozen', False):
        base_path = os.path.dirname(sys.executable)
    else:
        base_path = root()
    logs_dir = os.path.join(base_path, 'logs')
    os.makedirs(logs_dir, exist_ok=True)
    return logs_dir


init_logger()



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 3/18/2024 4:59 PM
@Description: Description
@File: lib.py
"""
import os
from typing import Any, List, Dict, Optional

import numpy as np
from dateutil import parser

from api_requester.utils.json_utils import are_json_equal


def is_na_no(sth) -> bool:
    """
    NaN、None或者空字符串返回True，其他情况返回False
    """
    if sth == 0:
        return False
    if not sth:
        return True
    if isinstance(sth, float):
        if np.isnan(sth):
            return True
    return False


def check_file_path():
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            _path = func(*args, **kwargs)
            return (_path and os.path.exists(_path)) and _path or None

        return __inner__

    return __wrapper__


def param_is_digit(param):
    return (type(param) is str and param.isdigit()) or type(param) is int


def get_class_attr_values(obj: object):
    result = list()
    for var_name, var_value in vars(obj).items():
        if not var_name.startswith('__') and not callable(var_value):
            result.append(var_value)
    return result


def split_list(lst, n):
    """将一组数字拆分成n个组，形成一个列表"""
    quotient = len(lst) // n
    remainder = len(lst) % n
    result = []
    start = 0
    for i in range(n):
        if i < remainder:
            end = start + quotient + 1
        else:
            end = start + quotient
        result.append(lst[start:end])
        start = end
    return result


def _get_val_from_list(items: list, k1, v1, k2, compare_json=False):
    """
    Traverse each item in the list, and obtain the value of k2 through
    the actual value of k1 and the expected value v1.
    :param items: List of dictionaries to search within.
    :param k1: The key to look up in each dictionary.
    :param v1: The value to match with the dictionary's value for the given key.
    :param k2: The key whose value should be returned if a match is found.
    :return: The value associated with k2 if a match is found, otherwise None.
    """
    if items and isinstance(items, list):
        for item in items:
            item_value = item.get(k1)
            if compare_json:
                if are_json_equal(v1, item_value):
                    return item.get(k2)
            if item_value == v1:
                return item.get(k2)
    return None


def get_key_from_dict(items: dict, k, v):
    if items and isinstance(items, dict):
        for key, value in items.items():
            if value.get(k) == v:
                return key
    return None


def _get_val_from_dict(items: dict, k1, k2):
    """
    Traverse each item in the dictionary and find the value of k2 in the value of k1.
    @param items:
    @param k1: A key in items.
    @param k2:
    @return: None, val
    """
    if items and isinstance(items, dict):
        for key, value in items.items():
            if key == k1:
                return value.get(k2)
    return None


def _find_and_validate_single_item(items, k1, v1, compare_json=False, validate=True):
    """
    Traverse each item in the list, and return the item through the actual value of k1 and the expected value v1.
    :param items: List of dictionaries to search within.
    :param k1: The key to look up in each dictionary.
    :param v1: The value to match with the dictionary's value for the given key.
    :param compare_json: If True, compare the value to the JSON representation of the item. Default is False.
    :param validate: If True, validates that exactly one item matches the criteria.
                     If False, returns all matched items without validation.
    :return: A single matching item if validate is True and exactly one match is found;
             otherwise, returns the list of matched items or None if no match is found.
    :raises ValueError: If validate is True and multiple items match the criteria.
    """
    matched_items = list()
    if items and isinstance(items, list):
        for item in items:
            item_value = item.get(k1)
            if compare_json:
                if are_json_equal(v1, item_value):
                    matched_items.append(item)
                    continue
            if v1 == item_value:
                matched_items.append(item)
    if not validate:
        return matched_items
    if len(matched_items) == 1:
        return matched_items[0]
    elif len(matched_items) == 0:
        return None
    else:
        raise ValueError("Multiple items match the criteria.")


def _get_first_item_from_list(items, k1=None, v1=None, sort_by=None):
    """
    @param items:
    @param k1:
    @param v1:
    @return: None, item
    """
    if items and isinstance(items, list):
        if sort_by is not None:
            items = sorted(items, key=lambda x: format_value(x[sort_by]), reverse=True)
        for item in items:
            if v1 is None or k1 is None:
                return item
            if v1 == item.get(k1):
                return item
    return None


def _get_last_item_from_list(items, k1=None, v1=None, sort_by=None):
    if items and isinstance(items, list):
        # 先排序，如果提供了排序键
        if sort_by is not None:
            items = sorted(items, key=lambda x: format_value(x.get(sort_by)),
                           reverse=True if sort_by.startswith('-') else False)

        # 遍历列表，找到最后一个符合条件的项
        last_item = None
        for item in items:
            if v1 is None or k1 is None or v1 == item.get(k1):
                last_item = item
        return last_item
    return None


def is_included(items, k, v):
    """
    Traverse each item in the list to determine whether the value of k is consistent with the actual value v.
    @param items:
    @param v:
    @param k:
    @return: True or False.
    """
    if items and isinstance(items, list):
        for i in items:
            if i.get(k, None) == v:
                return True
    return False


def apply_is_included(key="name"):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            items = func(*args, **kwargs)
            return is_included(items, key, kwargs.get("name"))

        return __inner__

    return __wrapper__


def get_val_from_list(k1="name", k2="id", v1=None, compare_json=False):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            v = kwargs.get("name") if v1 is None else v1
            return _get_val_from_list(res, k1, v, k2, compare_json)

        return __inner__

    return __wrapper__


def get_item_from_list(k1="name", compare_json=False):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            return _find_and_validate_single_item(res, k1, kwargs.get("name"), compare_json)

        return __inner__

    return __wrapper__


def get_first_item_from_list(k1=None, sort_by=None):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            return _get_first_item_from_list(res, k1, kwargs.get("name"), sort_by)

        return __inner__

    return __wrapper__


def get_first_val_from_list(extract_key, k1=None, sort_by=None):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            item = _get_first_item_from_list(res, k1, kwargs.get("name"), sort_by)
            return item.get(extract_key)

        return __inner__

    return __wrapper__


def get_last_val_from_list(extract_key, k1=None, sort_by=None):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            item = _get_last_item_from_list(res, k1, kwargs.get("name"), sort_by)
            return item.get(extract_key)

        return __inner__

    return __wrapper__


def get_val_from_dict(k2):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            res = func(*args, **kwargs)
            return _get_val_from_dict(res, kwargs.get("key"), k2)

        return __inner__

    return __wrapper__


def get_value_from_nested_dict_by_list(data, path):
    """
    从嵌套的字典中按路径获取值

    参数:
    data (dict):
    path (list): 包含键的列表，表示路径

    返回:
    获取到的值，如果路径无效则返回 None
    """
    if not path:
        return data
    if not data:
        return data
    key = path[0]
    if key in data:
        return get_value_from_nested_dict_by_list(data[key], path[1:])
    else:
        return None


def get_value_from_nested_dict(data, path):
    path_list = path.split(".")
    return get_value_from_nested_dict_by_list(data, path_list)


def mkdirs(func):
    def __wrapper__(*args, **kwargs):
        dir_path = func(*args, **kwargs)
        if not os.path.exists(dir_path):
            os.makedirs(dir_path, exist_ok=True)
        return dir_path

    return __wrapper__


def truncate_string(s, max_length):
    if type(s) is str and type(max_length) is int:
        return s[:max_length if max_length < len(s) else len(s)]
    return s


def handle_construction(construction_func, error_message):
    """
    处理 YAML 标签构建的异常。
    """
    try:
        return construction_func()
    except Exception as e:
        print("{0}: {1}".format(error_message, e))
        return str()


def is_datetime_string(date_str):
    try:
        parser.parse(date_str)
        return True
    except (ValueError, TypeError):
        return False


def format_value(value):
    if value is None:
        raise Exception("None value exists.")
    if isinstance(value, int):
        return value
    elif isinstance(value, str):
        if is_datetime_string(value):
            return parser.parse(value)
        else:
            return value


def retrieve_item_by_key_value(items, key, value, compare_json=False, validate=True):
    """
    Retrieve a single item from a list of dictionaries based on a key-value match.

    :param items: List of dictionaries to search within.
    :param key: The key to look up in each dictionary.
    :param value: The value to match with the dictionary's value for the given key.
    :param compare_json: If True, compare the value to the JSON representation of the item. Default is False.
    :param validate: If True, validates that exactly one item matches the criteria.
                     If False, returns all matched items without validation.
    :return: The matching item or None if no match is found. Raises an exception if multiple matches are found.
    :raises ValueError: If multiple items match the criteria.
    """
    return _find_and_validate_single_item(items, key, value, compare_json, validate)


def are_none_or_empty(*values: Any) -> bool:
    """
    检查多个值是否都为 None 或空字符串。

    :param values: 需要检查的值。
    :return: 如果所有值都是 None 或空字符串，返回 True；否则返回 False。
    """
    processed_values = []
    for value in values:
        if isinstance(value, str):
            processed_values.append(value.strip())
        elif value is None:
            processed_values.append(value)
        else:
            return False
    return all(value in (None, "") for value in processed_values)


def first_unassociated_perms(trees, key):
    """
    遍历树，返回第一分支为key=false的从根节点到子节点id的列表，并保留所有key=true的数据。

    :param trees: 树列表
    :param key: 属性名称
    :return: 包含ID的列表
    """
    flag = "__false_value_flag__"

    def traverse(node, paths, results):
        if paths is None:
            paths = []
        if node.get("id") is not None:
            paths.append(node["id"])
        for child in node.get("children", []):
            traverse(child, paths.copy(), results)
        else:
            if node.get(key, True):
                results.extend(paths)
            elif flag in results:
                results.extend(paths)
                results.remove(flag)

    all_results = [flag]
    for tree in trees:
        traverse(tree, [], all_results)
    return list(set(all_results))


def apply_first_unassociated_perms(key):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            trees = func(*args, **kwargs)
            return first_unassociated_perms(trees, key)

        return __inner__

    return __wrapper__


def extract_values(records: List[Dict], key: Optional[str] = None, first_value: bool = False) -> List[Any]:
    """
    从字典列表中提取每个字典的指定键的值，或者根据参数返回第一个值。

    该方法假设列表中的每个字典都包含至少一个键值对。
    如果 `first_value` 为 True，则返回每个字典的第一个值；
    如果提供了 `key`，则返回每个字典中对应键的值；
    如果既未提供 `key` 也未设置 `first_value` 为 True，则返回空列表。
    
    :param records: 一个字典列表，每个字典至少包含一个键值对。
    :param key: （可选）指定键来提取对应的值。如果未提供且 `first_value` 为 False，则返回空列表。
    :param first_value: （可选）是否返回每个字典的第一个值。如果为 True，将忽略 `key` 参数。
    :return: 包含提取值的列表。
    """
    if first_value:
        return [next(iter(record.values())) for record in records]
    elif key:
        return [record.get(key) for record in records]
    else:
        return []


def apply_extract_values(key=None, first_value=False):
    def __wrapper__(func):
        def __inner__(*args, **kwargs):
            records = func(*args, **kwargs)
            return extract_values(records, key, first_value)

        return __inner__

    return __wrapper__



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: subject_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminSubjectAuthApi:
    """
    The AdminSubjectAuthApi was generated by Generator from the SubjectAuthController.java file.
    """

    @post('/auth/subject/login')
    def auth_subject_login_api(self, *args, **kwargs): ...

    @get('/auth/subject/logout')
    def auth_subject_logout_api(self, *args, **kwargs): ...

    @get('/auth/subject/me')
    def auth_subject_me_api(self, *args, **kwargs): ...

    @get('/auth/subject/verify/organization-code')
    def verify_organization_code_api(self, *args, **kwargs): ...



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 5/15/2024 2:30 PM
@Description: Description
@File: authorize_ecoa.py
"""
import time

from loguru import logger

from api_requester.core.admin.dto.subject_jwt_authentication_request import SubjectJwtAuthenticationRequest
from api_requester.core.admin.dto.user_on_board_dto import UserOnBoardDto
from api_requester.core.admin.service.subject_auth_service import AdminSubjectAuthService
from api_requester.core.common.service.subject_auth_service import CommonSubjectAuthService
from api_requester.dto.biz_base import BizBase
from api_requester.dto.user import EClinicalUser
from api_requester.http.sample_headers import SampleHeaders
from api_requester.utils.constant import AppEnum
from api_requester.utils.rsa import encrypt_password


class AuthorizeEdiary(BizBase, AdminSubjectAuthService, CommonSubjectAuthService):

    def __init__(self, user: EClinicalUser):
        BizBase.__init__(self, user)
        self.login_app = self.user.app
        self.user.app = AppEnum.ADMIN.code
        self.time_mills = time.time()
        self.user_onboard_dto = UserOnBoardDto(-1)
        AdminSubjectAuthService.__init__(self)
        CommonSubjectAuthService.__init__(self)

    def login(self):
        try:
            self._auth()
            self.user.app = self.login_app
            self._app_auth()
            logger.info("{0} logs in to {1} eDiary successfully.".format(self.user, self.login_app))
        except Exception as e:
            logger.error("{0} failed to log in to {1} eDiary.".format(self.user, self.login_app))
            raise Exception(f"Authorize Failed: {e}")

    def _auth(self):
        self.time_mills = time.time()
        encrypt_pwd = encrypt_password(self.user.password)
        jwt_authentication_request_dto = SubjectJwtAuthenticationRequest(
            self.user.username, encrypt_pwd, organizationCode=self.user.org_code)
        response = self.auth_subject_login(jwt_authentication_request_dto)
        if response is None:
            raise Exception(f"LoginParams failed: {response}")
        if response.get("jwtAuthenticationResponse") is None:
            token = response.get("token")
        else:
            token = response.get("jwtAuthenticationResponse").get("token")
        self.headers = SampleHeaders().add_authorization(token).to_h()
        self.time_mills = time.time()
        return response

    def _app_auth(self):
        response = self.subject_auth_login()
        if response.get("jwtAuthenticationResponse") is None:
            token = response.get("token")
        else:
            token = response.get("jwtAuthenticationResponse").get("token")
        self.headers = SampleHeaders().add_authorization(token).to_h()
        self.time_mills = time.time()

    def admin_auth(self):
        return self._auth()



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/09/06 14:41
@Description: Description
@File: user_on_board_application_service.py
"""
from api_requester.core.admin.api.user_on_board_application_api import AdminUserOnBoardApplicationApi
from api_requester.core.admin.dto.cross_user_user_on_board_dto import CrossUserUserOnBoardDto
from api_requester.core.admin.dto.user_on_board_dto import UserOnBoardDto


class AdminUserOnBoardApplicationService(AdminUserOnBoardApplicationApi):
    """
    The AdminUserOnBoardApplicationService was generated by Generator from the UserOnBoardApplicationController.java file.
    """

    def __init__(self):
        AdminUserOnBoardApplicationApi.__init__(self)

    def get_company_list(self):
        return self.get_company_list_api()

    def get_user_onboard_application_list(self, company_id: int = None):
        return self.get_user_onboard_application_list_api(params=dict(companyId=company_id))

    def on_board(self, user_on_board_dto: UserOnBoardDto = None):
        return self.on_board_api(json=user_on_board_dto)

    def entry_portal(self):
        return self.entry_portal_api()

    def login_portal(self, cross_user_user_on_board_dto: CrossUserUserOnBoardDto = None):
        return self.login_portal_api(json=cross_user_user_on_board_dto)



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: reset_password_email_request_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class ResetPasswordEmailRequestDto(BaseDto):
    """
    The ResetPasswordEmailRequestDto was generated by Generator from the ResetPasswordEmailRequestDto.java file.
    """
    userId: str = None



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 6/12/2024 2:20 PM
@Description: Description
@File: biz_base.py
"""
import time
from abc import abstractmethod, ABC
from typing import Optional

from requests import Response

from api_requester.dto.user import EClinicalUser


class BizBase(ABC):

    def __init__(self, user=None, headers=None, last_result=None, refresh_content_type=True):
        self.user: Optional[EClinicalUser] = user
        self.headers: dict = headers or dict()
        self.last_kwargs: dict = dict()
        self.last_result: Optional[Response] = last_result
        self.time_mills = time.time()
        self.refresh_content_type: bool = refresh_content_type
        self.raises_exception: bool = True
        self.allure_attach: bool = False

    @abstractmethod
    def login(self): ...



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/08 14:20
@Description: Description
@File: ecoa_auth_service.py
"""
from api_requester.core.admin.api.ecoa_auth_api import AdminEcoaAuthApi
from api_requester.core.admin.dto.ecoa_onboard_request_dto import EcoaOnboardRequestDto
from api_requester.core.admin.dto.jwt_authentication_request import JwtAuthenticationRequest
from api_requester.core.admin.dto.reset_password_email_request_dto import ResetPasswordEmailRequestDto
from api_requester.core.admin.dto.sso_token_retrieve_dto import SsoTokenRetrieveDto


class AdminEcoaAuthService(AdminEcoaAuthApi):
    """
    The AdminEcoaAuthService was generated by Generator from the EcoaAuthController.java file.
    """

    def __init__(self):
        AdminEcoaAuthApi.__init__(self)

    def auth_ecoa_login(self, authentication_request: JwtAuthenticationRequest = None):
        return self.auth_ecoa_login_api(json=authentication_request)

    def create_authentication_token_from_sso(self, token_retrieve: SsoTokenRetrieveDto = None):
        return self.create_authentication_token_from_sso_api(json=token_retrieve)

    def auth_ecoa_logout(self):
        return self.auth_ecoa_logout_api()

    def auth_ecoa_me(self):
        return self.auth_ecoa_me_api()

    def reset_password_email(self, reset_password_email_request_dto: ResetPasswordEmailRequestDto = None):
        return self.reset_password_email_api(json=reset_password_email_request_dto)

    def ecoa_study_list(self):
        return self.ecoa_study_list_api()

    def onboard(self, ecoa_onboard_dto: EcoaOnboardRequestDto = None):
        return self.onboard_api(json=ecoa_onboard_dto)



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/07/04 09:01
@Description: Description
@File: subject_jwt_authentication_request.py
"""
from dataclasses import dataclass

from api_requester.core.admin.dto.jwt_authentication_request import JwtAuthenticationRequest


@dataclass
class SubjectJwtAuthenticationRequest(JwtAuthenticationRequest):
    """
    The SubjectJwtAuthenticationRequest was generated by Generator from the SubjectJwtAuthenticationRequest.java file.
    """
    organizationCode: str = None



"""
@Author: xiaodong.li
@Date: 2023-07-25 13:33:15
LastEditors: xiaodong.li
LastEditTime: 2023-07-25 13:33:15
@Description: eclinical_requests.py
"""
import copy
import os
import time
from functools import wraps

import requests
from requests import Response
from requests_toolbelt import MultipartEncoder

from api_requester.dto.base_dto import BaseDto, build_file_dto
from api_requester.dto.biz_base import BizBase
from api_requester.http.app_url import AppUrl
from api_requester.http.exceptions import ApiResponseException
from api_requester.http.sample_headers import SampleHeaders


def get(api):
    def __wrapper__(func):
        @url(api)
        @build_request_data()
        @refresh_token()
        @refresh_headers()
        @get_request()
        @http_ok
        def __inner__(instance: BizBase, *args, **kwargs):
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def post(api):
    def __wrapper__(func):
        @url(api)
        @build_request_data()
        @refresh_token()
        @refresh_headers()
        @post_request()
        @http_ok
        def __inner__(instance: BizBase, *args, **kwargs):
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def delete(api):
    def __wrapper__(func):
        @url(api)
        @build_request_data()
        @refresh_token()
        @refresh_headers()
        @delete_request()
        @http_ok
        def __inner__(instance: BizBase, *args, **kwargs):
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def put(api):
    def __wrapper__(func):
        @url(api)
        @build_request_data()
        @refresh_token()
        @refresh_headers()
        @put_request()
        @http_ok
        def __inner__(instance: BizBase, *args, **kwargs):
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def get_request():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            app_url = kwargs.pop("app_url")
            rsp = requests.get(app_url, **kwargs)
            kwargs.update(rsp=rsp)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def post_request():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            app_url = kwargs.pop("app_url")
            rsp = requests.post(app_url, **kwargs)
            kwargs.update(rsp=rsp)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def delete_request():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            app_url = kwargs.pop("app_url")
            rsp = requests.delete(app_url, **kwargs)
            kwargs.update(rsp=rsp)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def put_request():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            app_url = kwargs.pop("app_url")
            rsp = requests.put(app_url, **kwargs)
            kwargs.update(rsp=rsp)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def url(api):
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            url_kwargs = kwargs.pop("url_kwargs", {})
            if instance.user.external is False:
                app_url = AppUrl(instance.user.app, instance.user.test_env).which_url(
                    instance.user.app)(api, **url_kwargs)
            else:
                app_url = AppUrl(instance.user.app, instance.user.test_env).external_url(api, **url_kwargs)
            if app_url is None:
                raise Exception("The url is null.")
            kwargs.update(app_url=app_url)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def build_request_data():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            for key in ["json", "params"]:
                value = kwargs.get(key)
                if value is not None:
                    if issubclass(value.__class__, BaseDto):
                        kwargs[key] = value.to_dict()
                    elif isinstance(value, list):
                        kwargs[key] = [i.to_dict() if issubclass(i.__class__, BaseDto) else i for i in value]
                    elif isinstance(value, dict):
                        if key == "params":
                            base_dto_keys = [k for k, v in value.items() if issubclass(v.__class__, BaseDto)]
                            if len(base_dto_keys) > 0:
                                base_dto_dict = dict()
                                for k in base_dto_keys:
                                    dto_dict = value.pop(k).to_dict()
                                    if dto_dict.keys() & base_dto_dict:
                                        raise Exception("Duplicate keys found in BaseDto dictionaries")
                                    base_dto_dict.update(dto_dict)
                                if base_dto_dict.keys() & value:
                                    raise Exception("BaseDto keys overlap with non-BaseDto keys")
                                value.update(base_dto_dict)
                        else:
                            kwargs[key] = {k: v.to_dict() if issubclass(v.__class__, BaseDto) else v for k, v in
                                           value.items()}
            data = kwargs.get("data")
            if data is None and "multipart_encoder_kwargs" in kwargs:
                multipart_encoder_kwargs = kwargs.pop("multipart_encoder_kwargs")
                if multipart_encoder_kwargs is not None:
                    multipart_encoder_data = list()
                    for k, v in multipart_encoder_kwargs.items():
                        if issubclass(v.__class__, BaseDto):
                            multipart_encoder_data.extend(v.build_multipart_fields(values_as_str=True, has_none=False))
                        elif isinstance(v, list) and all(
                                isinstance(file, str) and os.path.exists(file) and os.path.isfile(file) for file in v):
                            multipart_encoder_data.extend([(k, build_file_dto(file)) for file in v])
                        elif isinstance(v, str) and os.path.exists(v) and os.path.isfile(v):
                            multipart_encoder_data.append((k, build_file_dto(v)))
                        else:
                            multipart_encoder_data.append((k, v))
                    if len(multipart_encoder_data) > 0:
                        data = MultipartEncoder(fields=multipart_encoder_data)
                kwargs.update(data=data)
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def refresh_headers():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            headers = copy.deepcopy(instance.headers)
            sh = SampleHeaders(headers)
            if instance.refresh_content_type is True:
                sh.add_content_type("application/json")
            data = kwargs.get("data")
            if isinstance(data, MultipartEncoder):
                sh.add_content_type(data.content_type)
            kwargs.update(headers=sh.to_h())
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def refresh_token():
    def __wrapper__(func):
        def __inner__(instance: BizBase, *args, **kwargs):
            instance.user.external is False and (
                    int(time.time() - instance.time_mills) < 60 * 30 - 300 or instance.login())
            return func(instance, *args, **kwargs)

        return __inner__

    return __wrapper__


def http_ok(func):
    @wraps(func)
    def _http_ok(instance: BizBase, *args, **kwargs):
        try:
            rsp: Response = kwargs.pop("rsp")
            kwargs.pop("headers")
            instance.last_kwargs = kwargs
            instance.last_result = rsp
            content_type = rsp.headers.get("content-type")
            if rsp.status_code not in [200, 201]:
                raise ApiResponseException(rsp)
            if not content_type:
                raise ApiResponseException(rsp, message="The content-type in the response header is empty.")
            if "application/json" in content_type:
                proc_code = rsp.json().get("procCode")
                if proc_code not in [200, 201]:
                    raise ApiResponseException(rsp)
                else:
                    return rsp.json().get("payload")
            elif any(item in content_type for item in ["application/octet-stream", "application/vnd.ms-excel"]):
                return rsp.content
            else:
                raise ApiResponseException(rsp, message="Please handle the {0} request.".format(content_type))
        except Exception as e:
            if instance.raises_exception is True:
                raise
            else:
                # Handle non-exception case here if necessary
                print(f"Exception caught but not re-raised: {e}")

    return _http_ok



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: user_on_board_application_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminUserOnBoardApplicationApi:
    """
    The AdminUserOnBoardApplicationApi was generated by Generator from the UserOnBoardApplicationController.java file.
    """
    
    @get('/user/onboard/company')
    def get_company_list_api(self, *args, **kwargs): ...
    
    @get('/user/onboard/applications')
    def get_user_onboard_application_list_api(self, *args, **kwargs): ...
    
    @post('/user/onboard')
    def on_board_api(self, *args, **kwargs): ...
    
    @get('/user/entry/portal')
    def entry_portal_api(self, *args, **kwargs): ...
    
    @post('/user/entry/portal')
    def login_portal_api(self, *args, **kwargs): ...
    


# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: subject_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class CommonSubjectAuthApi:
    """
    The CommonSubjectAuthApi was generated by Generator from the SubjectAuthController.java file.
    """

    @post('/subject/auth/login')
    def subject_auth_login_api(self, *args, **kwargs): ...

    @get('/subject/refresh')
    def subject_refresh_api(self, *args, **kwargs): ...

    @get('/subject/auth/logout')
    def subject_auth_logout_api(self, *args, **kwargs): ...

    @get('/subject/me')
    def subject_me_api(self, *args, **kwargs): ...

    @get('/subject/name')
    def subject_api(self, *args, **kwargs): ...



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/08 14:20
@Description: Description
@File: ecoa_onboard_request_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class EcoaOnboardRequestDto(BaseDto):
    """
    The EcoaOnboardRequestDto was generated by Generator from the EcoaOnboardRequestDto.java file.
    """
    sponsorId: int = None
    studyId: int = None
    envId: int = None



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/22 10:32
@Description: Description
@File: portal_login_t_ime.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class PortalLoginTIme(BaseDto):
    """
    The PortalLoginTIme was generated by Generator from the PortalLoginTIme.java file.
    """
    portalLoginTime: int = None



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: user_on_board_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class UserOnBoardDto(BaseDto):
    """
    The UserOnBoardDto was generated by Generator from the UserOnBoardDto.java file.
    """
    applicationId: int
    sponsorId: int = None
    studyId: int = None
    envId: int = None
    workForCompanyId: int = None
    userId: int = None
    userType: str = None
    roleId: int = None
    token: str = None
    permissionId: int = None
    companyLevelLogin: bool = False



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 7/24/2023 3:48 PM
@Description: Description
@File: sample_headers.py
"""


class SampleHeaders(object):
    def __init__(self, headers=None):
        self.headers = {"Content-Type": "application/json", "Connection": "close"} if headers is None else headers

    def add_header(self, **kwargs):
        self.headers.update(kwargs)
        return self

    def to_h(self):
        return self.headers

    def add_authorization(self, token):
        return self.add_header(Authorization=token)

    def add_content_type(self, content_type):
        return self.add_header(**{"Content-Type": content_type})



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/22 10:32
@Description: Description
@File: ecoa_auth_service.py
"""
from typing import List

from api_requester.core.common.api.ecoa_auth_api import CommonEcoaAuthApi
from api_requester.core.common.dto.portal_login_t_ime import PortalLoginTIme


class CommonEcoaAuthService(CommonEcoaAuthApi):
    """
    The CommonEcoaAuthService was generated by Generator from the EcoaAuthController.java file.
    """

    def __init__(self):
        CommonEcoaAuthApi.__init__(self)

    def create_authentication_token(self, portal_login_time: PortalLoginTIme = None):
        return self.create_authentication_token_api(json=portal_login_time)

    def refresh_and_get_authentication_token(self):
        return self.refresh_and_get_authentication_token_api()

    def logout(self):
        return self.logout_api()

    def all_study_logout(self, tokens: List[str] = None):
        return self.all_study_logout_api(json=tokens)

    def me(self):
        return self.me_api()

    def ecoa_account(self):
        return self.ecoa_account_api()

    def change_password(self, ecoa_account_change_password_dto=None):
        return self.change_password_api(json=ecoa_account_change_password_dto)

    def change_study_language(self, language_id: int = None):
        return self.change_study_language_api(params=dict(languageId=language_id))



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/08 14:20
@Description: Description
@File: ecoa_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminEcoaAuthApi:
    """
    The AdminEcoaAuthApi was generated by Generator from the EcoaAuthController.java file.
    """

    @post('/auth/ecoa/login')
    def auth_ecoa_login_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/login/sso')
    def create_authentication_token_from_sso_api(self, *args, **kwargs): ...

    @get('/auth/ecoa/logout')
    def auth_ecoa_logout_api(self, *args, **kwargs): ...

    @get('/auth/ecoa/me')
    def auth_ecoa_me_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/reset_password')
    def reset_password_email_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/study-list')
    def ecoa_study_list_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/onboard')
    def onboard_api(self, *args, **kwargs): ...



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 5/15/2025 3:11 PM
@Description: Description
@File: test_api_requester.py
"""
import json
import unittest

from api_requester.core.call_api import ApiRequester
from api_requester.utils.constant import AppEnum, EdcAppType
from api_requester.utils.decrypt import decrypt


class TestApiRequester(unittest.TestCase):
    @staticmethod
    def test_app_login():
        c = ApiRequester("auto_api_coding", "Admin@123", "For CODING automated testing", "Study", "dev03", "dev",
                         app=AppEnum.CODING.code, company="For internal automated testing", role="DM")
        c.login()

    @staticmethod
    def test_ecoa_login():
        c = ApiRequester("CRC01", "7IG4CALi", app=AppEnum.EDC.code, test_env="dev03", ttype=EdcAppType.ECOA.name)
        c.login()
        assert c.user.study == "CRN04894-13"
        response = c.request("get", "/mobile/user/ecoa-study-language")
        assert response.json().get("payload")

    @staticmethod
    def test_ediary_login():
        c = ApiRequester("31176557", "886506", app=AppEnum.EDC.code, test_env="dev03", ttype=EdcAppType.EDIARY.name)
        c.login()
        response = c.request("get", "/study/information")
        assert response.json().get("payload").get("name") == "CRN04894-13"

    @staticmethod
    def test_ediary_login_with_org_code():
        c = ApiRequester("76548847", "340196", app=AppEnum.EDC.code, test_env="dev01", ttype=EdcAppType.EDIARY.name,
                         org_code="62B64A")
        c.login()
        response = c.request("get", "/study/information")
        assert response.json().get("payload").get("name") == "Study-113-963"

    @staticmethod
    def test_ediary_data_with_org_code():
        c = ApiRequester("76548847", "340196", app=AppEnum.EDC.code, test_env="dev01", ttype=EdcAppType.EDIARY.name,
                         org_code="62B64A")
        c.login()
        response = c.request("post", "/e-diary-app/offline/subject-version")
        payload = response.json().get("payload")
        node = decrypt(payload, is_no_padding=True)
        print(json.loads(node))


# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 1/8/2025 3:04 PM
@Description: Description
@File: setup.py
"""

import setuptools
from setuptools import find_packages

from src.api_requester import __version__

version = __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="eclinical_requester",
    version=version,
    author="xiaodong.li",
    author_email="",
    description="edetek api requester",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://example.com",
    install_requires=[
        'lxml>=4.8.0',
        'requests>=2.28.2',
        'PyYAML>=6.0',
        'requests-toolbelt>=0.10.1',
        'python-dateutil>=2.9.0.post0',
        'numpy>=1.23.4',
        'pycryptodome>=3.17',
    ],
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    classifiers=[
        "Programming Language :: Python :: 3.9",
    ],
    include_package_data=True,
    package_data={
        'api_requester.docs': ['*.yaml'],  # 列出所有需要包含的文档类型
    }
)



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: subject_auth_service.py
"""
from api_requester.core.common.api.subject_auth_api import CommonSubjectAuthApi


class CommonSubjectAuthService(CommonSubjectAuthApi):
    """
    The CommonSubjectAuthService was generated by Generator from the SubjectAuthController.java file.
    """

    def __init__(self):
        CommonSubjectAuthApi.__init__(self)

    def subject_auth_login(self):
        return self.subject_auth_login_api()

    def subject_refresh(self):
        return self.subject_refresh_api()

    def subject_auth_logout(self):
        return self.subject_auth_logout_api()

    def subject_me(self):
        return self.subject_me_api()

    def subject(self):
        return self.subject_api()



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 12/23/2020 2:32 PM
@Description: Description
@File: path.py
"""
import os


def root():
    return os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__)))))


def project_path():
    return os.path.dirname(os.path.dirname(os.path.realpath(__file__)))


def docs_path():
    return os.path.join(project_path(), "docs")



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/22 10:32
@Description: Description
@File: ecoa_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class CommonEcoaAuthApi:
    """
    The CommonEcoaAuthApi was generated by Generator from the EcoaAuthController.java file.
    """
    
    @post('/ecoa/auth/login')
    def create_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/ecoa/refresh')
    def refresh_and_get_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/ecoa/auth/logout')
    def logout_api(self, *args, **kwargs): ...
    
    @post('/ecoa/auth/all-study-logout')
    def all_study_logout_api(self, *args, **kwargs): ...
    
    @get('/ecoa/me')
    def me_api(self, *args, **kwargs): ...
    
    @get('/ecoa/name')
    def ecoa_account_api(self, *args, **kwargs): ...
    
    @post('/ecoa/change-password')
    def change_password_api(self, *args, **kwargs): ...
    
    @post('/ecoa/change-study-rel-language')
    def change_study_language_api(self, *args, **kwargs): ...
    